==> cms-db_v0.6.tar.gz: admin/main.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

function showmenu() {
	document.getElementById("menu").style.display = "block";
}
function hidemenu() {
	document.getElementById("menu").style.display = "none";
	menuinactive();
	barinactive("bar-menu");
}
function switchmenu() {
	if (document.getElementById("menu").style.display == "none") {
		showmenu();
		baractive("bar-menu");
	} else {
		hidemenu();
	}
}
function menuinactive() {
	document.getElementById("menu-pages").className = "menuinactive";
	document.getElementById("menu-files").className = "menuinactive";
	document.getElementById("menu-includes").className = "menuinactive";
	document.getElementById("menu-settings").className = "menuinactive";
	document.getElementById("menu-template").className = "menuinactive";
	document.getElementById("menu-space").className = "menuinactive";
	document.getElementById("menu-perms").className = "menuinactive";
	document.getElementById("menu-backup").className = "menuinactive";
	document.getElementById("menu-gbook").className = "menuinactive";
	document.getElementById("menu-stats").className = "menuinactive";
	document.getElementById("menu-recyclebin").className = "menuinactive";
}
function menuactive(foo) {
	document.getElementById(foo).className = "menuactive";
}
function baractive(foo) {
	document.getElementById(foo).className = "baractive";
}
function barinactive(foo) {
	document.getElementById(foo).className = "barinactive";
}
function bar(foo) {
	if (document.getElementById("menu").style.display == "none") {
		barinactive(foo);
	}
}
function init() {
	$("#all").css("visibility", "visible");
	if (document.getElementById("iconcontainer")) {
		$("#iconcontainer").css("visibility", "visible");
		$("#iconcontainer").css("bottom", "-60px");
		$("#iconcontainer").animate({bottom: "0"}, 1000);
	}
	if (document.getElementById("desktop")) {
		$("#desktop").hide().fadeIn(1000);
	}
	$("#bar").css("top", - 40 - $("#tabs").height() + "px" );
	$("#tabs").css("top", - 16 - $("#tabs").height() + "px" );
	$("#bar").animate({top: "0"}, 1000);
	$("#tabs").animate({top: "24"}, 1000);
	$("#javascript").css("display", "none");
	if (window.location.hash == "") {
		window.location.hash = "tabs;"
	}
	if (document.getElementById("date") && document.getElementById("time")) {
		setDateInvisible(true);
		time();
	}
}
function buttonactive(foo) {
	buttoninactive()
	document.getElementById(foo).className = "buttonactive";
}
function buttoninactive() {
	document.getElementById("logout").className = "buttoninactive";
	document.getElementById("preview").className = "buttoninactive";
	document.getElementById("info").className = "buttoninactive";
}
function time () {
	var now = new Date();
	var weekday = now.getDay(); //Wochentag ermitteln
	var dayarray = new Array("Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag"); //Array
	var day = now.getDate(); //Tag ermitteln
	var month = now.getMonth(); //Monat ermitteln
	var montharray = new Array("Januar", "Februar", unescape("M%E4rz"), "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Dezember"); //Array
	var year = now.getFullYear(); //Jahr ermitteln
	var hour = now.getHours(); //Stunden ermitteln
	var min = now.getMinutes(); //Minuten ermitteln
	if (min < 10) { min = "0"+min; }
	document.getElementById("time").firstChild.nodeValue = hour+":"+min;
	document.getElementById("date").firstChild.nodeValue = dayarray[weekday]+", "+day+". "+montharray[month]+" "+year;
	timeout = window.setTimeout("time()", 5000);
}
function setDateVisible() {
	$("#date").fadeIn("normal");
}
function setDateInvisible(noeffect) {
	if (noeffect != true) {
		$("#date").fadeOut("normal");
	} else {
		$("#date").hide();
	}
}

==> cms-db_v0.7.9.tar.gz: admin/main.js <==
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

function showmenu() {
	document.getElementById("menu").style.display = "block";
}
function hidemenu() {
	document.getElementById("menu").style.display = "none";
	menuinactive();
	barinactive("bar-menu");
}
function switchmenu() {
	if (document.getElementById("menu").style.display == "none") {
		showmenu();
		baractive("bar-menu");
	} else {
		hidemenu();
	}
}
function menuinactive() {
	$("#menu > a").removeClass("menuactive").addClass("menuinactive");
}
function menuactive(foo) {
	document.getElementById(foo).className = "menuactive";
}
function baractive(foo) {
	document.getElementById(foo).className = "baractive";
}
function barinactive(foo) {
	document.getElementById(foo).className = "barinactive";
}
function bar(foo) {
	if (document.getElementById("menu").style.display == "none") {
		barinactive(foo);
	}
}
function init() {
	$("#all").css("visibility", "visible");
	if (document.getElementById("iconcontainer")) {
		$("#iconcontainer").css("visibility", "visible");
		$("#iconcontainer").css("bottom", "-60px");
		$("#iconcontainer").animate({bottom: "0"}, 1000);
	}
	if (document.getElementById("desktop")) {
		$("#desktop").hide().fadeIn(1000);
	}
	$("#bar").css("top", - 40 - $("#tabs").height() + "px" );
	$("#tabs").css("top", - 16 - $("#tabs").height() + "px" );
	if (jQuery.browser.opera == false) {
		$("#throbber").fadeOut(1000).queue(function(){ $(this).remove() });
	} else {
		$("#throbber").remove();
	}
	$("#bar").animate({top: "0"}, 1000);
	$("#tabs").animate({top: "24"}, 1000);
	if (window.location.hash == "") {
		window.location.hash = "tabs;"
	}
	if (document.getElementById("date") && document.getElementById("time")) {
		setDateInvisible(true);
		time();
	}
	// WYMeditor 0.5b2 doesn't support jQuery 1.3.x
	// TODO: update this since jQuery 1.3+ is now used
	// Insted of live() we are doing this for new tabs in tabs.js
	//$("a").live("click", function() {
	//	$(this).blur();
	//});
	$("a").click(function() {
		$(this).blur();
	});
}
function buttonactive(foo) {
	buttoninactive()
	document.getElementById(foo).className = "buttonactive";
}
function buttoninactive() {
	document.getElementById("logout").className = "buttoninactive";
	document.getElementById("preview").className = "buttoninactive";
	document.getElementById("info").className = "buttoninactive";
}
function time () {
	var now = new Date();
	var weekday = now.getDay(); //Wochentag ermitteln
	var dayarray = new Array("Sonntag", "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag"); //Array
	var day = now.getDate(); //Tag ermitteln
	var month = now.getMonth(); //Monat ermitteln
	var montharray = new Array("Januar", "Februar", unescape("M%E4rz"), "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Dezember"); //Array
	var year = now.getFullYear(); //Jahr ermitteln
	var hour = now.getHours(); //Stunden ermitteln
	var min = now.getMinutes(); //Minuten ermitteln
	if (min < 10) { min = "0"+min; }
	document.getElementById("time").firstChild.nodeValue = hour+":"+min;
	document.getElementById("date").firstChild.nodeValue = dayarray[weekday]+", "+day+". "+montharray[month]+" "+year;
	timeout = window.setTimeout("time()", 5000);
}
function setDateVisible() {
	$("#date").stop(true,true).fadeIn("normal");
}
function setDateInvisible(noeffect) {
	if (noeffect != true) {
		$("#date").stop(true,true).fadeOut("normal");
	} else {
		$("#date").hide();
	}
}
